@@ -154,6 +154,7 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     logging.info( "NA in original dataframe:" )
     logging.info( f"{nna}" )
 
+    # Convert to categories and 
     df_leads_clean,imp = preprocessing_training_common( df=df_leads_clean,
                                                     config=config,
                                                     industry_dictionary=industry_dictionary,
@@ -163,6 +164,8 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
                                                     model_type=model_type,
                                                     imp=imp )
 
+    df_leads_clean = utils.reduce_mem_usage_category(df=df_leads_clean)
+    
     if(use_one_hot_encoding):
         df_leads_clean = utils.one_hot_encoding( df=df_leads_clean )
 
