@@ -1,10 +1,13 @@
-# AWSTools
+
+
 
 from ._aws_tools import *
 from ._memory_reduction import *
 from ._processing_tools import *
+from ._db_tools import *
 
 __all__ = (_aws_tools.__all__ +
            _memory_reduction.__all__+
-           _processing_tools.__all__)
+           _processing_tools.__all__+
+           _db_tools.__all__)
 
