@@ -181,9 +181,15 @@ def set_idemailstatus_target_column(df):
         logger.info('Setting E-Mail status target ')
         df = df[~df['IDEmailStatus'].isin([3, 5, 7, 32])]
         # C80 has an special conversion Status, setting it to 14 like the other campaigns
+        aux=df.loc[(df['idCampaign'] == '80') &
+               (df['IDEmailStatus'] ==31)].shape
+        logger.info(f'C80 successes: {aux}')
         df.loc[(df['idCampaign'] == '80') &
                (df['IDEmailStatus'] ==31),
             'IDEmailStatus']=14
+        aux=df.loc[(df['idCampaign'] == '80') &
+               (df['IDEmailStatus'] ==14)].shape
+        logger.info(f'C80 successes: {aux}')
         df.loc[df['IDEmailStatus'] != 14, 'IDEmailStatus'] = 0
         df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
         date_col = df['campaign_bulk_date']
